@@ -1,20 +1,29 @@
 """Defines the interface of a cachier caching core."""
 # This file is part of Cachier.
-# https://github.com/shaypal5/cachier
+# https://github.com/python-cachier/cachier
 
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/MIT-license
 # Copyright (c) 2016, Shay Palachy <shaypal5@gmail.com>
 
 import abc  # for the _BaseCore abstract base class
+import functools
+import hashlib
+
+
+def _default_hash_params(args, kwds):
+    # pylint: disable-next=protected-access
+    key = functools._make_key(args, kwds, typed=False)
+    return hashlib.sha256(str(hash(key)).encode()).hexdigest()
 
 
 class _BaseCore():
     __metaclass__ = abc.ABCMeta
 
-    def __init__(self, stale_after, next_time):
+    def __init__(self, stale_after, next_time, hash_params):
         self.stale_after = stale_after
         self.next_time = next_time
+        self.hash_func = hash_params if hash_params else _default_hash_params
         self.func = None
 
     def set_func(self, func):
@@ -22,16 +31,17 @@ class _BaseCore():
         any method is called"""
         self.func = func
 
+    def get_entry(self, args, kwds):
+        """Returns the result mapped to the given arguments in this core's
+        cache, if such a mapping exists."""
+        key = self.hash_func(args, kwds)
+        return self.get_entry_by_key(key)
+
     @abc.abstractmethod
     def get_entry_by_key(self, key):
         """Returns the result mapped to the given key in this core's cache,
         if such a mapping exists."""
 
-    @abc.abstractmethod
-    def get_entry(self, args, kwds, hash_params):
-        """Returns the result mapped to the given arguments in this core's
-        cache, if such a mapping exists."""
-
     @abc.abstractmethod
     def set_entry(self, key, func_res):
         """Maps the given result to the given key in this core's cache."""
