@@ -1,7 +1,7 @@
 """Persistent, stale-free memoization decorators for Python."""
 
 # This file is part of Cachier.
-# https://github.com/shaypal5/cachier
+# https://github.com/python-cachier/cachier
 
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/MIT-license
@@ -149,22 +149,33 @@ def cachier(
         core = _PickleCore(  # pylint: disable=R0204
             stale_after=stale_after,
             next_time=next_time,
+            hash_params=hash_params,
             reload=pickle_reload,
             cache_dir=cache_dir,
-            separate_files=separate_files
+            separate_files=separate_files,
+            wait_for_calc_timeout=wait_for_calc_timeout,
         )
     elif backend == 'mongo':
         if mongetter is None:
             raise MissingMongetter(
                 'must specify ``mongetter`` when using the mongo core')
         core = _MongoCore(
-            mongetter, stale_after, next_time, wait_for_calc_timeout)
+            mongetter=mongetter,
+            stale_after=stale_after,
+            next_time=next_time,
+            hash_params=hash_params,
+            wait_for_calc_timeout=wait_for_calc_timeout,
+        )
     elif backend == 'memory':
-        core = _MemoryCore(stale_after=stale_after, next_time=next_time)
+        core = _MemoryCore(
+            stale_after=stale_after,
+            next_time=next_time,
+            hash_params=hash_params,
+        )
     elif backend == 'redis':
         raise NotImplementedError(
             'A Redis backend has not yet been implemented. '
-            'Please see https://github.com/shaypal5/cachier/issues/4'
+            'Please see https://github.com/python-cachier/cachier/issues/4'
         )
     else:
         raise ValueError('specified an invalid core: {}'.format(backend))
@@ -183,7 +194,7 @@ def cachier(
                 _print = print
             if ignore_cache:
                 return func(*args, **kwds)
-            key, entry = core.get_entry(args, kwds, hash_params)
+            key, entry = core.get_entry(args, kwds)
             if overwrite_cache:
                 return _calc_entry(core, key, func, args, kwds)
             if entry is not None:  # pylint: disable=R0101
